-- This file handles any chat-related functions

local BFC_OldChatFrameHandler = nil;

-- Hook the chat frame handler to hide our chat events
function BFC_HookChat()
--	BFC_OldChatFrameHandler = ChatFrame_OnEvent;
--	ChatFrame_OnEvent = BFC_NewChatFrameHandler;
end

-- Override the chat frame handler to hide ping events
function BFC_NewChatFrameHandler(event)
	-- There is a channel
	if ( BFC_Options.EnablePings == true and strsub(event, 1, 16) == "CHAT_MSG_CHANNEL" and BFC_Options.Channel and arg9 and strlower(arg9) == strlower(BFC_Options.Channel)) then
		if(event ~= "CHAT_MSG_CHANNEL_LIST") then
			return;
		end
	end
	BFC_OldChatFrameHandler(event);
end


-- Join a chat channel
function BFC_JoinChannel(name)
	
	if(BFC_Config.channel and BFC_Config.channel ~= "") then
		LeaveChannelByName(BFC_Config.channel);
	end
	
	if(name ~= nil and name ~= "") then
		BFC_Print(string.format(BFC_Strings.msg_setchannel, name));
		BFC_Config.channel = name;
		BFC_Frame.joinchan = true;
	else
		BFC_Print(BFC_Strings.error_invalidchannel);
	end

end

-- Broadcast the channel to others
function BFC_BroadcastChannel(name)
	if(name ~= nil and name ~= "") then
		BFC_SendRaidMessage(string.format(BFC_Strings.msg_broadcastchan, name));
	end
end

-- Leave a chat channel
function BFC_LeaveChannel(name)
	--BFC_Print("Attempting to leave " .. name);
	
	
	if(name ~= nil) then
		--BFC_Print("Attempting to leave " .. name);
		LeaveChannelByName(name);
	end
end

-- Send a message to the raid/group
function BFC_SendRaidMessage(msg)
	if(msg == nil or msg == "") then return end
	
	if(GetNumRaidMembers() > 0) then
		SendChatMessage("<BFC> " .. msg, "RAID");
	elseif(GetNumPartyMembers() > 0) then
		SendChatMessage("<BFC> " .. msg, "PARTY");
	else
		BFC_Print(BFC_Strings.error_notingroup);
	end
end

-- Send a message over the chat channel
function BFC_SendChannelMessage(msg)
	local chanid;
	if ( BFC_Config.channel) then
		chanid = GetChannelName(BFC_Config.channel);
		if(chanid == 0) then
			BFC_Debug(string.format(BFC_Strings.error_channotfound, BFC_Config.channel));
			return;
		end
		-- replace 's' characters so the drunk filter doesn't mangle them
		--msg = string.gsub(msg, "s", "$");
		--msg = string.gsub(msg, "S", "");
		SendChatMessage("BFC" .. msg, "CHANNEL", nil, chanid);
	end
end

-- Receive a chat message from the channel
function BFC_ParseChatMessage(msg,author)
	
	if(string.sub(msg, 0, 3) ~= "BFC") then return end
	
	-- unmangle anything the drunk filter may have inserted
	if ( strsub(msg, strlen(msg)-7) == " ...hic!") then
		msg = strsub(msg, 1, strlen(msg)-8);
	end
	
	--msg = string.gsub(msg, "$", "s");
	--msg = string.gsub(msg, "", "S");

	--BFC_Print("parsing chat message");
	local cmd = string.sub(msg, 4,7);
	msg = string.sub(msg, 9);
	
	if(BFC_CanSendStatusUpdate(author) == true) then
		if(cmd == "ECBT") then
			BFC_PlayerEnterCombat(author);
		elseif(cmd == "LCBT") then
			BFC_PlayerLeaveCombat(author);
		elseif(cmd == "PING") then
			BFC_HandlePingRequest(msg);
		elseif(cmd == "RDIO") then
			BFC_HandleRadioRequest(msg);
		end
	end
	
	if(BFC_CanSendObjective(author) == true) then
		if(cmd == "OJTV") then
			BFC_HandleObjectiveRequest(msg);
		elseif(cmd == "CLER") then
			BFC_HandleClearObjectivesRequest(msg)
		end
	end
end

-- Crufty old code from before... might need this someday
--[[
if(BFC_NeedToJoinChan == true) then
		local status, mapName, instanceID = GetBattlefieldStatus();
		if(instanceID == nil) then
			instanceID = 0;
		end
		local channame = "BFC" .. BFC_GetLevelBracket() .. instanceID;
	
		if(BFC_Options.Channel and GetChannelName(BFC_Options.Channel) ~= 0) then
			BFC_Print(
			BFC_NeedToJoinChan = false;
		end

		BFC_Options.Channel = 0;
		
		--BFC_Print("BFC auto-joining channel: " .. channame);
	
		if (BFC_Options.Channel == nil or GetChannelName(BFC_Options.Channel) == 0 ) then
			local zoneChannel, channelName = JoinChannelByName(channame, nil, DEFAULT_CHAT_FRAME:GetID());
			
			BFC_Options.Channel = channame;

			if ( channelName ) then
				channame = channelName;
			end
			if ( not zoneChannel ) then
				return;
			end
			
			local i = 1;
	
			while ( DEFAULT_CHAT_FRAME.channelList[i] ) do
				i = i + 1;
			end
			DEFAULT_CHAT_FRAME.channelList[i] = channame;
			DEFAULT_CHAT_FRAME.zoneChannelList[i] = zoneChannel;
		else
			BFC_Print("already in channel " .. BFC_Options.Channel);
		end
	end]]
